# Changelog

<!-- changelogging: start -->

## [0.3.0](https://github.com/nekitdev/changelogging/tree/v0.3.0) (YYYY-MM-DD)

### Features

- Added cool features! ([#13](https://github.com/nekitdev/changelogging/pull/13))

### Changes

- Changed some things! ([#22](https://github.com/nekitdev/changelogging/pull/22))

### Fixes

- Fixed annoying bugs! ([#34](https://github.com/nekitdev/changelogging/pull/34))
